==> SimplyDualWielding-5.4.0%2B1.21.%286%2B%29-Fabric-sources.jar: eva/dualwielding/DualWieldingMain.java <==
package eva.dualwielding;

import eva.dualwielding.access.ServerPlayerAccess;
import eva.dualwielding.config.JsonConfigHelper;
import eva.dualwielding.init.ParticleInit;
import eva.dualwielding.network.AttackPayload;
import eva.dualwielding.network.ConfigPacket;
import eva.dualwielding.network.ListPacket;
import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.networking.v1.PayloadTypeRegistry;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_3222;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DualWieldingMain implements ModInitializer {

    public static final String MOD_ID = "sdw";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    private static boolean collectiveLoaded = false;

    public static boolean collectiveLoaded() {return collectiveLoaded;}

    @Override
    public void onInitialize() {
        JsonConfigHelper.init();
        ParticleInit.initServer();
        collectiveLoaded = FabricLoader.getInstance().isModLoaded("collective");

        PayloadTypeRegistry.configurationS2C().register(ConfigPacket.ID, ConfigPacket.CODEC);
        PayloadTypeRegistry.configurationS2C().register(ListPacket.ID, ListPacket.CODEC);
        PayloadTypeRegistry.playC2S().register(AttackPayload.TYPE, AttackPayload.STREAM_CODEC);

        ServerPlayNetworking.registerGlobalReceiver(AttackPayload.TYPE, (payload, context) -> {
            int entityId = payload.entityId();
            context.server().execute(() -> {
                class_3222 tp = context.player();
                tp.method_14234();
                if (context.player().method_51469().method_8469(entityId) != null) {
                    ((ServerPlayerAccess) tp).dualWielding$attackOffhand(tp.method_51469().method_8469(entityId));
                }
            });
        });

//        ServerPlayNetworking.registerGlobalReceiver(MinePacket.MinePayload.TYPE, (payload, context) -> {
//            context.server().execute(() -> {
//                ServerPlayer tp = context.player();
//                ((ServerPlayerGameModeAccess)tp.gameMode).dualWielding$handleBlockBreakingAction(payload.pos(), payload.action(), payload.direction(), tp.level().getMaxY(), payload.sequence());
//                    tp.connection.ackBlockChangesUpTo(payload.sequence());
//            });
//        });
    }
}

==> SimplyDualWielding-6.1.1%2B1.21.%286%2B%29-Fabric-sources.jar: eva/dualwielding/DualWieldingMain.java <==
package eva.dualwielding;

import eva.dualwielding.access.ServerPlayerAccess;
import eva.dualwielding.config.JsonConfigHelper;
import eva.dualwielding.init.ParticleInit;
import eva.dualwielding.network.AttackPayload;
import eva.dualwielding.network.BalancePacket;
import eva.dualwielding.network.ConfigPacket;
import eva.dualwielding.network.ListPacket;
import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.networking.v1.PayloadTypeRegistry;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_3222;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class DualWieldingMain implements ModInitializer {

    public static final String MOD_ID = "sdw";
    public static final Logger LOGGER = LoggerFactory.getLogger(MOD_ID);

    private static boolean collectiveLoaded = false;

    public static boolean collectiveLoaded() {return collectiveLoaded;}

    @Override
    public void onInitialize() {
        JsonConfigHelper.init();
        ParticleInit.initServer();
        collectiveLoaded = FabricLoader.getInstance().isModLoaded("collective");

        PayloadTypeRegistry.configurationS2C().register(ConfigPacket.ID, ConfigPacket.CODEC);
        PayloadTypeRegistry.configurationS2C().register(ListPacket.ID, ListPacket.CODEC);
        PayloadTypeRegistry.configurationS2C().register(BalancePacket.ID, BalancePacket.CODEC);
        PayloadTypeRegistry.playC2S().register(AttackPayload.TYPE, AttackPayload.STREAM_CODEC);

        ServerPlayNetworking.registerGlobalReceiver(AttackPayload.TYPE, (payload, context) -> {
            int entityId = payload.entityId();
            context.server().execute(() -> {
                class_3222 tp = context.player();
                tp.method_14234();
                if (context.player().method_51469().method_8469(entityId) != null) {
                    ((ServerPlayerAccess) tp).dualWielding$attackOffhand(tp.method_51469().method_8469(entityId));
                }
            });
        });
    }
}
